==> flutter_snow_blower-0.1.0%2B1.tar.gz: lib/src/templates/templates.dart <==
export 'generator/controller_generator.dart';
export 'generator/controller_test_generator.dart';
export 'generator/data_source_generator.dart';
export 'generator/data_source_test_generator.dart';
export 'generator/entity_generator.dart';
export 'generator/i18n_generator.dart';
export 'generator/i18n_generator_test.dart';
export 'generator/module_template.dart';
export 'generator/page_generator.dart';
export 'generator/page_test_generator.dart';
export 'generator/repository_generator.dart';
export 'generator/repository_test_generator.dart';
export 'generator/use_case_generator.dart';
export 'generator/use_case_test_generator.dart';
export 'generator/widget_generator.dart';
export 'generator/widget_test_generator.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___RELEASE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___RELEASE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___RELEASE.xml.dart';
export 'start/.vscode/launch.json.dart';
export 'start/app_flavor_values.dart';
export 'start/main.dart';
export 'start/main_dev.dart';
export 'start/main_production.dart';
export 'start/main_qa.dart';
export 'start/src/clean/app/app_module.dart';
export 'start/src/clean/app/app_widget.dart';
export 'start/src/clean/app/stores/auth/auth_store.dart';
export 'start/src/clean/data/data_sources/auth/auth_local_data_source.dart';
export 'start/src/clean/data/data_sources/auth/auth_remote_data_source.dart';
export 'start/src/clean/data/data_sources/feature/feature_local_data_source.dart';
export 'start/src/clean/data/data_sources/feature/feature_remote_data_source.dart';
export 'start/src/clean/data/mappers/auth_mapper.dart';
export 'start/src/clean/data/mappers/index.dart';
export 'start/src/clean/data/mappers/user_mapper.dart';
export 'start/src/clean/data/repositories/auth/auth_repository_impl.dart';
export 'start/src/clean/data/repositories/feature/feature_repository_impl.dart';
export 'start/src/clean/di/di.dart';
export 'start/src/clean/di/modules/local_module.dart';
export 'start/src/clean/di/modules/remote_module.dart';
export 'start/src/clean/domain/entities/auth_entity.dart';
export 'start/src/clean/domain/entities/auth_status.dart';
export 'start/src/clean/domain/entities/user_entity.dart';
export 'start/src/clean/domain/repositories/auth/auth_repository.dart';
export 'start/src/clean/domain/repositories/feature/feature_repository.dart';
export 'start/src/clean/domain/usecases/auth/get_auth_status_stream_use_case.dart';
export 'start/src/clean/domain/usecases/auth/get_user_stream_use_case.dart';
export 'start/src/clean/domain/usecases/auth/get_user_use_case.dart';
export 'start/src/clean/domain/usecases/auth/login_user_email_use_case.dart';
export 'start/src/clean/domain/usecases/auth/logout_user_use_case.dart';
export 'start/src/clean/domain/usecases/auth/register_user_email_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_future_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_stream_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_use_case.dart';
export 'start/src/clean/domain/usecases/feature/do_something_use_case.dart';
export 'start/src/mvc_modular/app_module.dart';
export 'start/src/mvc_modular/app_widget.dart';
export 'start/src/mvc_modular/shared/auth/auth_store.dart';
export 'start/src/mvc_modular/shared/auth/repositories/auth_repository.dart';
export 'start/src/mvc_modular/shared/auth/repositories/auth_repository_interface.dart';
export 'start/src/mvc_modular/shared/models/user_model.dart';
export 'start/src/shared/clients/dio_client.dart';
export 'start/src/shared/clients/hive_client.dart';
export 'start/src/shared/constants/constants.dart';
export 'start/src/shared/constants/features.dart';
export 'start/src/shared/extensions/extensions.dart';
export 'start/src/shared/helpers/error_mapper.dart';
export 'start/src/shared/helpers/validators.dart';
export 'start/src/shared/i18n/login_i18n.dart';
export 'start/src/shared/i18n/validators_i18n.dart';
export 'start/src/shared/pages/login/login_module.dart';
export 'start/src/shared/pages/login/pages/login/login_controller.dart';
export 'start/src/shared/pages/login/pages/login/login_page.dart';
export 'start/src/shared/pages/login/pages/register/register_controller.dart';
export 'start/src/shared/pages/login/pages/register/register_page.dart';
export 'start/src/shared/pages/splash/splash_controller.dart';
export 'start/src/shared/pages/splash/splash_module.dart';
export 'start/src/shared/pages/splash/splash_page.dart';
export 'start/src/shared/styles/app_bar_theme_app.dart';
export 'start/src/shared/styles/app_color_scheme.dart';
export 'start/src/shared/styles/app_text_theme.dart';
export 'start/src/shared/styles/app_theme_data.dart';
export 'start/src/shared/widgets/custom_alert_dialog/custom_alert_dialog.dart';
export 'start/src/shared/widgets/custom_alert_dialog/types/confirm_dialog.dart';
export 'start/src/shared/widgets/custom_alert_dialog/types/error_dialog.dart';
export 'start/src/shared/widgets/login/email_text_field_widget.dart';
export 'start/src/shared/widgets/login/password_text_field_widget.dart';
export 'start/src/shared/widgets/observer_future/observer_future.dart';
export 'start/test/clients/dio_client_test.dart';
export 'start/test/drawer_features_example_test.dart';
export 'start/test/i18n/i18n_test.dart';
export 'start/test/test_variants/flavors_test_variant.dart';

==> flutter_snow_blower-2021.2.0%2B1.tar.gz: lib/src/templates/templates.dart <==
export 'generator/controller_generator.dart';
export 'generator/controller_test_generator.dart';
export 'generator/data_source_generator.dart';
export 'generator/data_source_test_generator.dart';
export 'generator/entity_generator.dart';
export 'generator/i18n_generator.dart';
export 'generator/i18n_generator_test.dart';
export 'generator/module_template.dart';
export 'generator/page_generator.dart';
export 'generator/page_test_generator.dart';
export 'generator/repository_generator.dart';
export 'generator/repository_test_generator.dart';
export 'generator/use_case_generator.dart';
export 'generator/use_case_test_generator.dart';
export 'generator/widget_generator.dart';
export 'generator/widget_test_generator.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Dev___RELEASE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_Prod___RELEASE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___DEBUG.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___PROFILE.xml.dart';
export 'start/.idea/runConfigurations/Flutter_QA___RELEASE.xml.dart';
export 'start/.vscode/launch.json.dart';
export 'start/app_flavor_values.dart';
export 'start/main.dart';
export 'start/main_dev.dart';
export 'start/main_production.dart';
export 'start/main_qa.dart';
export 'start/src/clean/app/app_module.dart';
export 'start/src/clean/app/app_widget.dart';
export 'start/src/clean/app/stores/auth/auth_store.dart';
export 'start/src/clean/data/data_sources/auth/auth_local_data_source.dart';
export 'start/src/clean/data/data_sources/auth/auth_remote_data_source.dart';
export 'start/src/clean/data/data_sources/feature/feature_local_data_source.dart';
export 'start/src/clean/data/data_sources/feature/feature_remote_data_source.dart';
export 'start/src/clean/data/model/local/some_table.dart';
export 'start/src/clean/data/mappers/auth_mapper.dart';
export 'start/src/clean/data/mappers/index.dart';
export 'start/src/clean/data/mappers/user_mapper.dart';
export 'start/src/clean/data/repositories/auth/auth_repository_impl.dart';
export 'start/src/clean/data/repositories/feature/feature_repository_impl.dart';
export 'start/src/clean/di/di.dart';
export 'start/src/clean/di/modules/local_module.dart';
export 'start/src/clean/di/modules/remote_module.dart';
export 'start/src/clean/domain/entities/auth_entity.dart';
export 'start/src/clean/domain/entities/auth_status.dart';
export 'start/src/clean/domain/entities/user_entity.dart';
export 'start/src/clean/domain/repositories/auth/auth_repository.dart';
export 'start/src/clean/domain/repositories/feature/feature_repository.dart';
export 'start/src/clean/domain/usecases/auth/get_auth_status_stream_use_case.dart';
export 'start/src/clean/domain/usecases/auth/get_user_stream_use_case.dart';
export 'start/src/clean/domain/usecases/auth/get_user_use_case.dart';
export 'start/src/clean/domain/usecases/auth/login_user_email_use_case.dart';
export 'start/src/clean/domain/usecases/auth/logout_user_use_case.dart';
export 'start/src/clean/domain/usecases/auth/register_user_email_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_future_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_stream_use_case.dart';
export 'start/src/clean/domain/usecases/base/base_use_case.dart';
export 'start/src/clean/domain/usecases/feature/do_something_use_case.dart';
export 'start/src/mvc_modular/app_module.dart';
export 'start/src/mvc_modular/app_widget.dart';
export 'start/src/mvc_modular/shared/auth/auth_store.dart';
export 'start/src/mvc_modular/shared/auth/repositories/auth_repository.dart';
export 'start/src/mvc_modular/shared/auth/repositories/auth_repository_interface.dart';
export 'start/src/mvc_modular/shared/models/user_model.dart';
export 'start/src/shared/clients/dio_client.dart';
export 'start/src/shared/clients/hive_client.dart';
export 'start/src/shared/clients/moor/moor_db.dart';
export 'start/src/shared/clients/moor/dao/some_dao.dart';
export 'start/src/shared/constants/constants.dart';
export 'start/src/shared/constants/features.dart';
export 'start/src/shared/extensions/extensions.dart';
export 'start/src/shared/helpers/error_mapper.dart';
export 'start/src/shared/helpers/validators.dart';
export 'start/src/shared/i18n/login_i18n.dart';
export 'start/src/shared/i18n/validators_i18n.dart';
export 'start/src/shared/pages/login/login_module.dart';
export 'start/src/shared/pages/login/pages/login/login_controller.dart';
export 'start/src/shared/pages/login/pages/login/login_page.dart';
export 'start/src/shared/pages/login/pages/register/register_controller.dart';
export 'start/src/shared/pages/login/pages/register/register_page.dart';
export 'start/src/shared/pages/splash/splash_controller.dart';
export 'start/src/shared/pages/splash/splash_module.dart';
export 'start/src/shared/pages/splash/splash_page.dart';
export 'start/src/shared/styles/app_bar_theme_app.dart';
export 'start/src/shared/styles/app_color_scheme.dart';
export 'start/src/shared/styles/app_text_theme.dart';
export 'start/src/shared/styles/app_theme_data.dart';
export 'start/src/shared/widgets/custom_alert_dialog/custom_alert_dialog.dart';
export 'start/src/shared/widgets/custom_alert_dialog/types/confirm_dialog.dart';
export 'start/src/shared/widgets/custom_alert_dialog/types/error_dialog.dart';
export 'start/src/shared/widgets/login/email_text_field_widget.dart';
export 'start/src/shared/widgets/login/password_text_field_widget.dart';
export 'start/test/clients/dio_client_test.dart';
export 'start/test/drawer_features_example_test.dart';
export 'start/test/i18n/i18n_test.dart';
export 'start/test/test_variants/flavors_test_variant.dart';
